@@ -1,7 +1,6 @@
 import datetime
 from uuid import UUID
 
-import django
 import requests
 from django.db import transaction
 
@@ -29,10 +28,7 @@ def do_import(token, account_uuid, bank_account, since=None):
 
     for line_data in data:
         uuid = UUID(hex=line_data["id"])
-        if django.VERSION >= (3, 0, 0):
-            uuid_f = str(uuid)
-        else:
-            uuid_f = uuid
+        uuid_f = str(uuid)
         if StatementLine.objects.filter(uuid=uuid_f):
             continue
 
