@@ -5,6 +5,10 @@ your accountancy app. You should be able to use them them to provide
 initial create/update functionality.
 
 """
-from .transactions import SimpleTransactionForm, TransactionForm, LegForm, LegFormSet
-
-from .accounts import AccountForm
+from .accounts import AccountForm  # noqa
+from .transactions import (  # noqa
+    LegForm,
+    LegFormSet,
+    SimpleTransactionForm,
+    TransactionForm,
+)
